/*
 * info_mode.cc
 *
 * Copyright (C) 2012 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "info_mode.h"
#include "common.h"
#include "text.h"
#include "text_renderer.h"
#include "Arduino.h"



void InfoMode::draw_reset()
{
	switch( _flavour )
	{
	case 0: {
			PString str0( Text::_messages[ 0 ], MESSAGE_LEN * 4 );
			str0.begin();
			str0.format(
					"Propeller Clock mk.1   ...   "
					"Created by Tim and Dan Marston in 2012   ...   "
					"http://ed.am/dev/elec/propeller-clock" );
			Text::set_message_text( 0, str0 );
		}
		break;
	case 1: {
			PString str0( Text::_messages[ 0 ], MESSAGE_LEN );
			PString str1( Text::_messages[ 1 ], MESSAGE_LEN );
			str0.begin();
			str1.begin();
			str0.format( "RPM" );
			unsigned long millis = ::millis();
			str1.format( "%ld",
					(unsigned long)60 * 1000 / ( millis - _millis_last ) );
			_millis_last = millis;
			Text::set_message_text( 0, str0 );
			Text::set_message_text( 1, str1 );
		}
		break;
	}
}


void InfoMode::activate()
{
	_flavour = 0;
	_millis_last = ::millis();

	reset_messages();
}


void InfoMode::press()
{
	if( ++_flavour >= 2 )
		_flavour = 0;

	reset_messages();
}


void InfoMode::reset_messages()
{
	Text::reset();

	switch( _flavour )
	{
	case 0:
		Text::set_up_message( 0, Text::MODE_TOP | Text::MODE_THREEQUARTERS |
				Text::MODE_HSCROLL, Text::SCALE_SMALL );
		break;
	case 1:
		Text::set_up_message( 0, Text::MODE_TOP | Text::MODE_HALF,
				Text::SCALE_FAT );
		Text::set_up_message( 1, Text::MODE_BOTTOM | Text::MODE_HALF,
				Text::SCALE_FAT );
		break;
	}
}
