/*
 * settings_major_mode.h
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _SETTINGS_MAJOR_MODE_H_
#define _SETTINGS_MAJOR_MODE_H_


#include "major_mode.h"
#include "button.h"


class SettingsMajorMode : public MajorMode
{
public:

	SettingsMajorMode( Button &button );

	/**
	 * Called at the start of a "frame", before any segments are drawn.
	 */
	void draw_reset();

	/**
	 * Called when the mode is becoming active.
	 */
	void activate();

	/**
	 * Called when the mode is becoming inactive.
	 */
	void deactivate();

	/**
	 * Called when the button has been pressed.
	 */
	void press();

	/**
	 * Called when the button haas been long-pressed.
	 */
	void long_press();

private:

	/**
	 * Set up message buffers.
	 */
	void reset_messages();

	/** item we're setting */
	int _item;
	
	/** part of item that we're setting */
	int _part;

	/** the button */
	Button &_button;
};


#endif //_SETTINGS_MAJOR_MODE_H_
